@@ -540,7 +540,7 @@ TEST_F(Completer_frontend, builtin_others) {
                       "\\show",    "\\source",     "\\sql",        "\\status",
                       "\\system",  "\\use",        "\\warnings",   "\\watch"});
 
-#ifndef HAVE_V8
+#ifndef HAVE_JS
   expect.erase(std::find(expect.begin(), expect.end(), "\\js"));
 #endif
 
@@ -623,7 +623,7 @@ TEST_F(Completer_frontend, sql_table_o3) {
   EXPECT_AFTER_TAB("describe `pl", "describe `plugin`");
 }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST_F(Completer_frontend, js_keywords) {
   execute("\\js");
 
